@@ -19,10 +19,23 @@
 
 # You should have received a copy of the GNU General Public License
 # along with Grid Map.  If not, see <http://www.gnu.org/licenses/>.
+'''
+Grid Map provides wrappers that simplify submission and collection of jobs,
+in a more 'pythonic' fashion.
 
-from __future__ import absolute_import
+@author: Christian Widmer
+@author: Cheng Soon Ong
+@author: Dan Blanchard (dblanchard@ets.org)
+'''
 
-from .gridmap import Job, process_jobs, grid_map, pg_map
+from __future__ import absolute_import, print_function, unicode_literals
 
-__version__ = '0.9.2'
+from gridmap.job import Job, process_jobs, grid_map, pg_map
+
+
+# Version info
+__version__ = '0.9.3'
 VERSION = tuple(int(x) for x in __version__.split('.'))
+
+# For * imports
+__all__ = ['Job', 'process_jobs', 'grid_map', 'pg_map']
